# autumn-py

[![PyPI - Version](https://img.shields.io/pypi/v/autumn-py.svg)](https://pypi.org/project/autumn-py)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/autumn-py.svg)](https://pypi.org/project/autumn-py)

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install autumn-py
```

## License

`autumn-py` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
